@@ -29,12 +29,12 @@ import os
 import shutil
 import sys
 import time
+import uuid
 from collections import OrderedDict
 from pathlib import Path
 from typing import Any
 
 import argcomplete
-import pkg_resources
 import requests
 from loguru import logger
 
@@ -46,10 +46,12 @@ try:
 except ImportError:
     HAS_COLOUR = False
 
+import cr_api_client
 import cr_api_client.core_api as core_api
 import cr_api_client.provisioning_api as provisioning_api
 import cr_api_client.redteam_api as redteam_api
 import cr_api_client.scenario_api as scenario_api
+import cr_api_client.publish_api as publish_api
 
 # Initialize colorama
 if HAS_COLOUR:
@@ -66,7 +68,7 @@ else:
 def status_handler(args: Any) -> None:
     """Get platform status."""
 
-    client_version = pkg_resources.get_distribution("cr_api_client").version
+    client_version = cr_api_client.__version__
     logger.info("[+] cr_api_client version: {}".format(client_version))
 
     logger.info("[+] Platform status")
@@ -154,6 +156,30 @@ def status_handler(args: Any) -> None:
                 )
             )
 
+    # Redteam API
+    logger.info("  [+] Redteam API")
+    logger.info("    [+] address: {}".format(redteam_api.REDTEAM_API_URL))
+    try:
+        redteam_api_version = redteam_api.get_version()
+    except requests.exceptions.ConnectionError:
+        logger.warning(
+            "    [-] API status: " + colored("not running !", "white", "on_red")
+        )
+    else:
+        logger.info("    [+] API status: " + colored("OK", "grey", "on_green"))
+        logger.info("    [+] version: {}".format(redteam_api_version))
+        if client_version != redteam_api_version:
+            logger.info(
+                "    [-] "
+                + colored(
+                    "warning: Redteam API version ({}) mismatchs with cr_api_client version ({})".format(
+                        redteam_api_version, client_version
+                    ),
+                    "white",
+                    "on_red",
+                )
+            )
+
     # # Testing frontend
     # logger.info("  [+] Frontend")
     # logger.info(
@@ -189,7 +215,7 @@ def init_handler(args: Any) -> None:
     logger.info("[+] Checking version")
 
     # Check version
-    client_version = pkg_resources.get_distribution("cr_api_client").version
+    client_version = cr_api_client.__version__
 
     try:
         core_api_version = core_api.get_version()
@@ -300,30 +326,42 @@ def baseboxes_reload_handler(args: Any) -> None:
 # 'baseboxes_verify' related function
 #
 def baseboxes_verify_handler(args: Any) -> None:
-    """Verify available baseboxes (compare checksums)"""
+    """
+    Handler for the verification of the baseboxes
+    :param args: args.basebox_id (optional)
+    :return: None
+    """
 
     requested_basebox_id = args.basebox_id
 
     if requested_basebox_id is None:
         logger.info("[+] Verifying the checksums of available baseboxes")
-        baseboxes = core_api.fetch_baseboxes()
-        for basebox in baseboxes:
-            result = core_api.verify_basebox(basebox["id"])
-            logger.info(
-                "  [+] {} has the correct checksum: {}".format(
-                    result["basebox_id"], result["valid_checksum"]
+        result = core_api.verify_baseboxes()
+        for basebox_result in result["result"]:
+            if basebox_result["result"]:
+                logger.info(
+                    "[+] {} has the correct checksum.".format(
+                        basebox_result["basebox_id"]
+                    )
                 )
-            )
+            else:
+                logger.error(
+                    "[+] {} has not the correct checksum.".format(
+                        basebox_result["basebox_id"]
+                    )
+                )
+
     else:
         logger.info(
             "[+] Verifying the checksum of basebox {}".format(requested_basebox_id)
         )
         result = core_api.verify_basebox(requested_basebox_id)
-        logger.info(
-            "  [+] {} has the correct checksum: {}".format(
-                result["basebox_id"], result["valid_checksum"]
+        if result["valid_checksum"]:
+            logger.info("[+] {} has the correct checksum.".format(requested_basebox_id))
+        else:
+            logger.error(
+                "[+] {} has not the correct checksum.".format(requested_basebox_id)
             )
-        )
     logger.info("[+] Done")
 
 
@@ -389,7 +427,7 @@ def simu_create_handler(args: Any) -> None:
 
         logger.info("[+] Created simulation ID: '{}'".format(id_simulation))
     except Exception as e:
-        logger.info(f"Error when creating new simulation: '{e}'")
+        logger.error(f"Error when creating new simulation: '{e}'")
         sys.exit(1)
     finally:
         t2 = time.time()
@@ -642,12 +680,41 @@ def simu_run_handler(args: Any) -> None:
     # Parameters
     id_simulation = args.id_simulation
     use_install_time = args.use_install_time
+    net_start_capture = args.net_start_capture
+    iface = args.iface
+    pcap = args.pcap
+    filter = args.filter
 
     # Compute elpased time
     t1 = time.time()
 
     try:
-        core_api.start_simulation(id_simulation, use_install_time)
+        if net_start_capture is True:
+            try:
+                collecting_points = core_api.fetch_list_tap(id_simulation)
+                capture_in_progress = core_api.fetch_simulation(id_simulation)[
+                    "capture_in_progress"
+                ]
+
+                if collecting_points is None:
+                    errorMessage = "No capture points defined"
+                    raise ValueError(errorMessage)
+                if capture_in_progress is True:
+                    errorMessage = "A capture is already in progress"
+                    raise ValueError(errorMessage)
+                if not pcap and filter:
+                    errorMessage = "Filter defined without --net_pcap option"
+                    raise ValueError(errorMessage)
+
+                core_api.start_simulation(id_simulation, use_install_time)
+                core_api.net_start_capture(id_simulation, iface, pcap, filter)
+            except Exception as e:
+                logger.info(f"An error occurred while activating tap: '{e}'")
+                sys.exit(1)
+            else:
+                logger.info("[+] Redirect network traffic to the tap interface")
+        else:
+            core_api.start_simulation(id_simulation, use_install_time)
     except Exception as e:
         logger.info(f"Error when starting simulation: '{e}'")
         sys.exit(1)
@@ -731,6 +798,21 @@ def simu_status_handler(args: Any) -> None:
                         )
                     else:
                         logger.info("      [+] admin account: None")
+
+                    if node["cpe"] is not None:
+                        # Reworking CPE variable for proper display purposes :
+                        split_cpe = node["cpe"].split()
+                        logger.info("      [+] cpe:")
+                        for i, cpe in enumerate(split_cpe):
+                            logger.info(
+                                "        [+] {}: {}".format(
+                                    i,
+                                    cpe,
+                                )
+                            )
+                    else:
+                        logger.info("      [+] cpe: Unknown")
+
                 if node["type"] == "physical_machine":
                     logger.info(
                         "      [+] roles: {}".format(
@@ -848,6 +930,25 @@ def simu_halt_handler(args: Any) -> None:
         logger.info("Simulation halted")
 
 
+#
+# 'dataset_create_handler'
+#
+def dataset_create_handler(args: Any) -> None:
+    # Parameters
+    id_simulation = args.id_simulation
+    dont_check_logs_path = args.dont_check_logs_path
+
+    try:
+        core_api.create_dataset(
+            id_simulation, dont_check_logs_path=dont_check_logs_path
+        )
+    except Exception as e:
+        logger.info(f"Error when creating dataset: '{e}'")
+        sys.exit(1)
+    else:
+        logger.info("Dataset created")
+
+
 #
 # 'simu_destroy' simulation
 #
@@ -882,32 +983,130 @@ def simu_clone_handler(args: Any) -> None:
 
 
 #
-# 'simu_tap' simulation
+# 'net_set_tap' simulation
 #
-def simu_tap_handler(args: Any) -> None:
+def net_set_tap_handler(args: Any) -> None:
+    # Parameters
+    id_simulation = args.id_simulation
+    simu_nodes = {"switchs": args.switchs, "nodes": args.nodes}
+
+    try:
+        core_api.net_set_tap(id_simulation, simu_nodes)
+    except Exception as e:
+        core_api.net_unset_tap(id_simulation)
+        logger.info(f"Error when setting tap on simulation: '{e}'")
+        sys.exit(1)
+    else:
+        logger.info("Configure the network collecting points")
+
+
+#
+# 'net_unset_tap' simulation
+#
+def net_unset_tap_handler(args: Any) -> None:
+    # Parameters
+    id_simulation = args.id_simulation
+
+    try:
+        core_api.net_unset_tap(id_simulation)
+    except Exception as e:
+        logger.info(
+            f"Error when configurating the network collecting points on simulation: '{e}'"
+        )
+        sys.exit(1)
+    else:
+        logger.info("Reset the network collecting points configuration")
+
+
+#
+# 'net_list_tap' simulation
+#
+def net_list_tap_handler(args: Any) -> None:
+    # Parameters
+    id_simulation = args.id_simulation
+
+    try:
+        collecting_points = core_api.fetch_list_tap(id_simulation)
+        logger.info("[+] Collecting points : " + str(collecting_points))
+    except Exception as e:
+        logger.info(
+            f"Error when printing the network collecting points configuration on simulation: '{e}'"
+        )
+        sys.exit(1)
+
+
+#
+# 'net_list_pcaps' simulation
+#
+def net_list_pcaps_handler(args: Any) -> None:
+    # Parameters
+    id_simulation = args.id_simulation
+
+    try:
+        list_pcaps = core_api.fetch_pcaps(id_simulation)
+        if not list_pcaps:
+            errorMessage = "At least one capture must have been done"
+            raise ValueError(errorMessage)
+
+        logger.info("[+] Print the pcap files")
+        for pcap in list_pcaps:
+            logger.info("  [+] " + pcap)
+    except Exception as e:
+        logger.info(f"Error when printing pcap files on simulation: '{e}'")
+        sys.exit(1)
+
+
+#
+# 'net_start_capture' simulation
+#
+def net_start_capture_handler(args: Any) -> None:
     # Parameters
     id_simulation = args.id_simulation
     iface = args.iface
+    pcap = args.pcap
+    filter = args.filter
 
     try:
-        core_api.tap_simulation(id_simulation, iface)
+        collecting_points = core_api.fetch_list_tap(id_simulation)
+        capture_in_progress = core_api.fetch_simulation(id_simulation)[
+            "capture_in_progress"
+        ]
+
+        if collecting_points is None:
+            errorMessage = "No capture points defined"
+            raise ValueError(errorMessage)
+        if capture_in_progress is True:
+            errorMessage = "A capture is already in progress"
+            raise ValueError(errorMessage)
+        if not pcap and filter:
+            errorMessage = "Filter defined without --pcap option"
+            raise ValueError(errorMessage)
+
+        core_api.net_start_capture(id_simulation, iface, pcap, filter)
     except Exception as e:
-        logger.info(f"Error when setting tap on simulation: '{e}'")
+        logger.info(f"An error occurred while activating tap: '{e}'")
         sys.exit(1)
     else:
         logger.info("Redirect network traffic to the tap interface")
 
 
 #
-# 'simu_untap' simulation
+# 'net_stop_capture' simulation
 #
-def simu_untap_handler(args: Any) -> None:
+def net_stop_capture_handler(args: Any) -> None:
     # Parameters
     id_simulation = args.id_simulation
-    iface = args.iface
 
     try:
-        core_api.untap_simulation(id_simulation, iface)
+        capture_in_progress = core_api.fetch_simulation(id_simulation)[
+            "capture_in_progress"
+        ]
+
+        if capture_in_progress is False:
+            errorMessage = "No capture in progress"
+            raise ValueError(errorMessage)
+
+        core_api.net_stop_capture(id_simulation)
     except Exception as e:
         logger.info(f"Error when unsetting tap on simulation: '{e}'")
         sys.exit(1)
@@ -1128,6 +1327,144 @@ def topo_add_dga_handler(args: Any) -> None:
         sys.exit(1)
 
 
+#
+# 'topo_add_dns_server' handler
+#
+def topo_add_dns_server_handler(args: Any) -> None:
+    """Process a YAML topology file and add a DNS server."""
+
+    # Parameters
+    input_topology_file = args.input_topology_file
+    output_topology_file = args.output_topology_file
+    switch_name = args.switch_name
+
+    try:
+        # get the absolute path
+        input_topology_file = os.path.abspath(input_topology_file)
+        resources_dir = os.path.join(os.path.dirname(output_topology_file), "resources")
+
+        # Verify that the destination folder does not exist
+        if os.path.exists(resources_dir):
+            logger.info(f"[+] {resources_dir} already exists. It will be reused.")
+        else:
+            os.mkdir(resources_dir)
+
+        (topology_yaml, dns_conf_content) = core_api.topology_file_add_dns_server(
+            input_topology_file, switch_name, resources_dir
+        )
+        # write the topology
+        with open(output_topology_file, "w") as w:
+            w.write(topology_yaml)
+        logger.info(
+            f"[+] Topology updated. New topology stored at '{output_topology_file}'"
+        )
+
+        # write the resources
+        dnsmasq_d_dir = os.path.join(resources_dir, "dnsmasq.d")
+        if os.path.exists(dnsmasq_d_dir):
+            logger.info(f"[+] {dnsmasq_d_dir} already exists. It will be replaced.")
+            try:
+                if os.path.isfile(dnsmasq_d_dir):
+                    os.remove(dnsmasq_d_dir)
+                else:
+                    shutil.rmtree(dnsmasq_d_dir)
+            except OSError as e:
+                logger.info(
+                    f"[+] Error while removing {dnsmasq_d_dir} on processing {e.filename}: {e.strerror}."
+                )
+        os.mkdir(dnsmasq_d_dir)
+
+        dns_conf_file = os.path.join(dnsmasq_d_dir, "dns.conf")
+        Path(dns_conf_file).touch()
+        with open(dns_conf_file, "w") as conf_file:
+            conf_file.write(dns_conf_content)
+
+        logger.info(
+            f"[+] Resources created. DNS configuration stored in '{dns_conf_file}'"
+        )
+
+    except Exception as e:
+        logger.info(f"Error when adding a DNS server to a topology: '{e}'")
+        sys.exit(1)
+
+
+#
+# 'datasets_list_handler' simulation
+#
+def datasets_list_handler(args: Any) -> None:
+    try:
+        datasets = publish_api.fetch_datasets()
+        logger.info("[+] Datasets : " + json.dumps(datasets))
+    except Exception as e:
+        logger.info(f"Error when printing publish datasets: '{e}'")
+        sys.exit(1)
+
+
+#
+# 'datasets_get_handler' simulation
+#
+def datasets_get_handler(args: Any) -> None:
+    # Parameters
+    dataset_id = uuid.UUID(args.dataset_id)
+
+    try:
+        dataset = publish_api.fetch_dataset_by_uuid(dataset_id)
+        logger.info("[+] Dataset : " + json.dumps(dataset))
+    except Exception as e:
+        logger.info(f"Error when printing publish dataset: '{e}'")
+        sys.exit(1)
+
+
+#
+# 'datasets_delete_handler' simulation
+#
+def datasets_delete_handler(args: Any) -> None:
+    # Parameters
+    dataset_id = uuid.UUID(args.dataset_id)
+
+    force = args.force
+    keep_remote_data = args.keep_remote_data
+
+    try:
+        publish_api.delete_dataset(
+            dataset_id, delete_remote_data=not keep_remote_data, force=force
+        )
+        logger.info(f"[+] Deleting dataset with uuid '{str(dataset_id)}'")
+    except Exception as e:
+        logger.info(f"Error when deleting publish dataset: '{e}'")
+        sys.exit(1)
+
+
+#
+# 'datasets_delete_all_handler' simulation
+#
+def datasets_delete_all_handler(args: Any) -> None:
+    try:
+        proceed = True
+        while (reply := input("Are you sure ? [y/n]").lower()) not in {"y", "n"}:
+            logger.info("All datasets will be deleted.")
+        if reply == "y":
+            proceed = True
+        if reply == "n":
+            proceed = False
+
+        if not proceed:
+            logger.info("Stopping.")
+            sys.exit(1)
+        else:
+            force = args.force
+            keep_remote_data = args.keep_remote_data
+
+            # remove resources_dir
+            publish_api.delete_all_datasets(
+                delete_remote_data=not keep_remote_data, force=force
+            )
+            logger.info("[+] Deleting all datasets")
+    except Exception as e:
+        logger.info(f"Error when deleting publish datasets: '{e}'")
+        sys.exit(1)
+
+
 def set_core_api_url(core_api_url: str) -> str:
     logger.info("  [+] Using core API URL: {}".format(core_api_url))
     core_api.CORE_API_URL = core_api_url
@@ -1345,6 +1682,25 @@ def main() -> None:
         dest="use_install_time",
         help="Indicates that VM installation time will be used to set VMs boot time",
     )
+    parser_simu_run.add_argument(
+        "--net_start_capture",
+        action="store_true",
+        dest="net_start_capture",
+        help="Redirect network traffic to the tap interface",
+    )
+    parser_simu_run.add_argument(
+        "--net_iface", type=str, dest="iface", help="The tap network interface"
+    )
+    parser_simu_run.add_argument(
+        "--net_pcap",
+        action="store_true",
+        dest="pcap",
+        default=False,
+        help="Records network streams in a pcap",
+    )
+    parser_simu_run.add_argument(
+        "-f", type=str, dest="filter", default="", help="Tcpdump filter"
+    )
 
     # 'simu_status' simulation command
     parser_simu_status = subparsers.add_parser(
@@ -1391,6 +1747,22 @@ def main() -> None:
     parser_simu_halt.set_defaults(func=simu_halt_handler)
     parser_simu_halt.add_argument("id_simulation", type=int, help="The simulation id")
 
+    # 'simu_halt' simulation command
+    parser_dataset_create = subparsers.add_parser(
+        "dataset_create",
+        help="Create the dataset after stopping a simulation",
+    )
+    parser_dataset_create.set_defaults(func=dataset_create_handler)
+    parser_dataset_create.add_argument(
+        "id_simulation", type=int, help="The simulation id"
+    )
+    parser_dataset_create.add_argument(
+        "--dont-check-logs-path",
+        action="store_true",
+        dest="dont_check_logs_path",
+        help="Bypass the check for the logs path in the topology file",
+    )
+
     # 'simu_destroy' simulation command
     parser_simu_destroy = subparsers.add_parser(
         "simu_destroy",
@@ -1428,28 +1800,97 @@ def main() -> None:
     parser_simu_delete.set_defaults(func=simu_delete_handler)
     parser_simu_delete.add_argument("id_simulation", type=int, help="The simulation id")
 
-    # 'simu_tap' simulation command
-    parser_simu_tap = subparsers.add_parser(
-        "simu_tap",
+    # 'net_start_capture' simulation command
+    parser_net_start_capture = subparsers.add_parser(
+        "net_start_capture",
         help="Redirect network traffic to the tap interface",
     )
-    parser_simu_tap.set_defaults(func=simu_tap_handler)
-    parser_simu_tap.add_argument("id_simulation", type=int, help="The simulation id")
-    parser_simu_tap.add_argument("iface", type=str, help="The tap network interface")
-
-    # 'simu_untap' simulation command
-    parser_simu_untap = subparsers.add_parser(
-        "simu_untap",
-        help="Stop redirection of network traffic",
+    parser_net_start_capture.set_defaults(func=net_start_capture_handler)
+    parser_net_start_capture.add_argument(
+        "id_simulation", type=int, help="The simulation id"
+    )
+    parser_net_start_capture.add_argument(
+        "-i", type=str, dest="iface", help="The tap network interface"
+    )
+    parser_net_start_capture.add_argument(
+        "--pcap",
+        action="store_true",
+        dest="pcap",
+        default=False,
+        help="Records network streams in a pcap",
+    )
+    parser_net_start_capture.add_argument(
+        "-f", type=str, dest="filter", default="", help="Tcpdump filter"
+    )
+
+    # 'net_stop_capture' simulation command
+    parser_net_stop_capture = subparsers.add_parser(
+        "net_stop_capture",
+        help="Stop redirection of network traffic to the tap interface",
+    )
+    parser_net_stop_capture.set_defaults(func=net_stop_capture_handler)
+    parser_net_stop_capture.add_argument(
+        "id_simulation", type=int, help="The simulation id"
+    )
+
+    # 'net_set_tap' simulation command
+    parser_net_set_tap = subparsers.add_parser(
+        "net_set_tap",
+        help="Configure the network collecting points",
+    )
+    parser_net_set_tap.set_defaults(func=net_set_tap_handler)
+    parser_net_set_tap.add_argument("id_simulation", type=int, help="The simulation id")
+    parser_net_set_tap.add_argument(
+        "--switch",
+        required=False,
+        nargs="+",
+        action="append",
+        dest="switchs",
+        help="List of simulation nodes",
+    )
+    parser_net_set_tap.add_argument(
+        "--nodes",
+        type=str,
+        action="append",
+        required=False,
+        dest="nodes",
+        help="List of simulation nodes",
+    )
+
+    # 'net_unset_tap' simulation command
+    parser_net_unset_tap = subparsers.add_parser(
+        "net_unset_tap",
+        help="Reset the network collecting points configuration",
+    )
+    parser_net_unset_tap.set_defaults(func=net_unset_tap_handler)
+    parser_net_unset_tap.add_argument(
+        "id_simulation", type=int, help="The simulation id"
+    )
+
+    # 'net_list_tap' simulation command
+    parser_net_list_tap = subparsers.add_parser(
+        "net_list_tap",
+        help="Print the network collecting points configuration",
+    )
+    parser_net_list_tap.set_defaults(func=net_list_tap_handler)
+    parser_net_list_tap.add_argument(
+        "id_simulation", type=int, help="The simulation id"
+    )
+
+    # 'net_list_pcaps' simulation command
+    parser_net_list_pcaps = subparsers.add_parser(
+        "net_list_pcaps",
+        help="Print the pcap files",
+    )
+    parser_net_list_pcaps.set_defaults(func=net_list_pcaps_handler)
+    parser_net_list_pcaps.add_argument(
+        "id_simulation", type=int, help="The simulation id"
     )
-    parser_simu_untap.set_defaults(func=simu_untap_handler)
-    parser_simu_untap.add_argument("id_simulation", type=int, help="The simulation id")
-    parser_simu_untap.add_argument("iface", type=str, help="The tap network interface")
 
     # 'node_stats' simulation command
     parser_node_stats = subparsers.add_parser(
         "node_stats",
-        help="Get resource statistics of a node",
+        help="Get resource statistics of a node. Note: you can get the node IDs using the simu_status command.",
     )
     parser_node_stats.set_defaults(func=node_stats_handler)
     parser_node_stats.add_argument("id_node", type=int, help="The node unique id")
@@ -1457,7 +1898,7 @@ def main() -> None:
     # 'node_memorydump' simulation command
     parser_node_nmemorydump = subparsers.add_parser(
         "node_memorydump",
-        help="Get the full raw memory dump of a node's RAM",
+        help="Get the full raw memory dump of a node's RAM. Note: you can get the node IDs using the simu_status command.",
     )
     parser_node_nmemorydump.set_defaults(func=node_memorydump_handler)
     parser_node_nmemorydump.add_argument("id_node", type=int, help="The node unique id")
@@ -1502,6 +1943,7 @@ def main() -> None:
         dest="websites",
         help="List of websites to add, taken from the websites catalog",
     )
+
     # 'topo_add_dga' command
     parser_topo_add_dga = subparsers.add_parser(
         "topo_add_dga",
@@ -1557,6 +1999,36 @@ def main() -> None:
         help="Directory to write the resources",
     )
 
+    # 'topo_add_dns_server' command
+    parser_topo_add_dns_server = subparsers.add_parser(
+        "topo_add_dns_server", help="Add a DNS server to a topology."
+    )
+    parser_topo_add_dns_server.set_defaults(func=topo_add_dns_server_handler)
+    parser_topo_add_dns_server.add_argument(
+        "-t",
+        "--topology",
+        type=str,
+        required=True,
+        dest="input_topology_file",
+        help="Path to the input YAML topology file",
+    )
+    parser_topo_add_dns_server.add_argument(
+        "-o",
+        "--output",
+        type=str,
+        required=True,
+        dest="output_topology_file",
+        help="Path to the output YAML topology file that will be created",
+    )
+    parser_topo_add_dns_server.add_argument(
+        "-s",
+        "--switch",
+        type=str,
+        required=True,
+        dest="switch_name",
+        help="Switch name on which to add a DNS server",
+    )
+
     # -----------------------
     # --- Provisioning options
     # -----------------------
@@ -1797,6 +2269,68 @@ def main() -> None:
         "id_simulation", type=int, help="The simulation id"
     )
 
+    # -------------------
+    # --- Publish options
+    # -------------------
+
+    # 'datasets_list' command
+    parser_datasets_list = subparsers.add_parser(
+        "datasets_list",
+        help="List all available datasets",
+    )
+    parser_datasets_list.set_defaults(func=datasets_list_handler)
+
+    # 'datasets_get' command
+    parser_datasets_get = subparsers.add_parser(
+        "datasets_get",
+        help="Get the full manifest of a specific dataset",
+    )
+    parser_datasets_get.set_defaults(func=datasets_get_handler)
+    parser_datasets_get.add_argument("dataset_id", type=str, help="The dataset id")
+
+    # 'datasets_delete' command
+    parser_datasets_delete = subparsers.add_parser(
+        "datasets_delete",
+        help="Delete a specific dataset",
+    )
+    parser_datasets_delete.set_defaults(func=datasets_delete_handler)
+    parser_datasets_delete.add_argument("dataset_id", type=str, help="The dataset id")
+    parser_datasets_delete.add_argument(
+        "--force",
+        action="store_true",
+        required=False,
+        default=False,
+        help="Force the deletion of the datasets (deletion happens even in case of errors, e.g. in manifest building)",
+    )
+    parser_datasets_delete.add_argument(
+        "--keep-remote-data",
+        action="store_true",
+        required=False,
+        default=False,
+        help="Delete only the data that is stored on the publish server (keep data on, e.g. the cloud)",
+    )
+
+    # 'datasets_delete_all' command
+    parser_datasets_delete_all = subparsers.add_parser(
+        "datasets_delete_all",
+        help="Delete all datasets",
+    )
+    parser_datasets_delete_all.set_defaults(func=datasets_delete_all_handler)
+    parser_datasets_delete_all.add_argument(
+        "--force",
+        action="store_true",
+        required=False,
+        default=False,
+        help="Force the deletion of the datasets (deletion happens even in case of errors, e.g. in manifest building)",
+    )
+    parser_datasets_delete_all.add_argument(
+        "--keep-remote-data",
+        action="store_true",
+        required=False,
+        default=False,
+        help="Delete only the data that is stored on the publish server (keep data on, e.g. the cloud)",
+    )
+
     argcomplete.autocomplete(parser)
 
     if len(sys.argv) == 1:
