@@ -156,8 +156,9 @@ def provisioning_execute(
     wait: bool = True,
     timeout: int = 10800,
 ) -> Tuple[bool, str]:
-    """Process YAML configuration file and generate a new provisioning
-    chronology.
+    """Apply provisioning configuration defined in YAML file on simulation defined in
+    argument ID OR on machines defined in file. The ``wait`` parameter defines if the
+    function wait for task to complete or not.
 
     """
 
@@ -250,7 +251,10 @@ def provisioning_ansible(
     wait: bool = True,
     timeout: int = 3600,
 ) -> Tuple[bool, str]:
-    """Apply ansible playbook(s)s on targets."""
+    """Apply ansible playbooks on specified target(s). The ``wait`` parameter defines if
+    the function wait for task to complete or not.
+
+    """
 
     if playbook_path is None:
         raise Exception("provisioning_file parameter cannot be None")
@@ -459,7 +463,7 @@ def provisioning_stop(task_id: str) -> dict:
 def provisioning_wait_until_complete(
     task_id: str, log_suffix: str = None, timeout: int = 3600
 ) -> dict:
-    """wait until provisioning task representing by its id is completed."""
+    """Wait until provisioning task representing by its id is completed."""
 
     start_time = time.time()
 
